#### Please select the sections that you would like to print

Select All
Case Information
Party
Causes
Disposition Events
Events and Hearings
Print

# Case Information

MGCV20-10699 | A.J. Davis Property Management vs John Patrick Chancey,Tabbatha Lynn Hensley

Case Number
MGCV20-10699

Court
Magistrate Civil

File Date
12/04/2020

Case Type
Dispossessory/Distress Warrant

Case Status
Closed

# Party

Plaintiff
A.J. Davis Property Management

Active Attorneys

Pro Se

Defendant
Chancey, John Patrick

DOB
XX/XX/1972

Gender
Male

Race
White

Active Attorneys

Pro Se

Defendant
Hensley, Tabbatha Lynn

DOB
XX/XX/1983

Gender
Female

Race
White

Active Attorneys

Pro Se

# Cause of Action

File Date | Cause of Action | Type | Filed By | Filed Against
--- | --- | --- | --- | ---
12/04/2020 | Dispossessory/Distress Warrant | Action | 39677 | 39677

# Disposition Events

01/07/2021 Judgment

Judicial Officer
Moss, Mary Kathryn

Judgment Type
Judgment

Award

Judgment For: Plaintiff

Verdict to Plaintiff:

Compensatory: $3,940.00

Verdict on Cross/Counter Claim:

# Events and Hearings

- 12/04/2020 Dispossessory Filed

- 12/04/2020 Cause Of Action

  Action
  Dispossessory/Distress Warrant

  File Date
  12/04/2020

- 12/07/2020 Service - Sent to Sheriff's Department (DW)

- 12/08/2020 Tacked And Mailed

  Comment
  Dep. N. Meyers #744

- 12/08/2020 Tacked And Mailed

  Comment
  Dep N Meyers

- 12/11/2020 Dispossessory Answer

- 01/07/2021 Dispossessory Hearing DW

  Original Type
  Dispossessory Hearing DW

  Judicial Officer
  Moss, Mary Kathryn

  Hearing Time
  10:00 AM

  Result
  Hearing Held

  Comment
  Ans by John Patrick Chancey/No per juris over Tabbatha Lynn Hensley

- 01/07/2021 Writ - Of Possession

  Comment
  Rent = 950.00 per month; money judgment as to John Patrick Chancey